@@ -1,11 +1,14 @@
 package JSON::Parser::Regexp;
 
-use Mouse;
 use utf8;
-use Kavorka;
 use Regexp::Grammars;
 
-our $VERSION = '0.09';
+our $VERSION = '0.10';
+
+sub new {
+    my $class = shift;
+    return bless {}, $class;
+}
 
 sub T::JSON::X {
     my ($self) = @_;
